==> opensubdiv-3.1.0-1-i686.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/all_14.js <==
var searchData=
[
  ['validate',['validate',['../a00903.html#a3566e1a9ec7fedc6e4fc47fab7c18532',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['validatefulltopology',['validateFullTopology',['../a00691.html#adaa22b025e8615d6e4281a86b794e5df',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory::Options']]],
  ['validatetopology',['validateTopology',['../a00923.html#a544d8f43ad23d13e196a9e3ba246d7df',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::validateTopology()'],['../a00667.html#a640a101c65375bded32722376e651f97',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyLevel::ValidateTopology()']]],
  ['validationcallback',['ValidationCallback',['../a00923.html#adb073794f0d56ccbf4c24ffae81ac6fe',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['value_5ftype',['value_type',['../a00883.html#a0caff2a05d659a02367f0f31ae29e45c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::ConstArray::value_type()'],['../a00887.html#a0caff2a05d659a02367f0f31ae29e45c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::Array::value_type()']]],
  ['valueindices',['valueIndices',['../a00663.html#a123fe78d0e97dc72f5dfd9f27f93f699',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyDescriptor::FVarChannel']]],
  ['valuetag',['ValueTag',['../a00911.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['valuetag',['ValueTag',['../a00911.html#afa63533ac54c95a41f1dda16085401b0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel::ValueTag']]],
  ['valuetagarray',['ValueTagArray',['../a00903.html#a59542ed688e97fbb07d38d8488416d9b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['valuetagsize',['ValueTagSize',['../a00911.html#a889d7ecab94d64e8abd73e4d632db45f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel::ValueTag']]],
  ['valuetopologymatches',['valueTopologyMatches',['../a00903.html#ab72baf3e3db74e2af11b59dbf18312e4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['vertexbuffer',['VertexBuffer',['../a00835.html#a722ca2b35d7001c0eeb6298f2c3704ca',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh']]],
  ['vertexbufferbinding',['VertexBufferBinding',['../a00763.html#a2d85a5ed6ddcef5023c9ef2e6fdd38a5',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::D3D11PatchTable::VertexBufferBinding()'],['../a00791.html#a02af2ea2e9328a776b5b0bb3edf88864',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::GLPatchTable::VertexBufferBinding()'],['../a00823.html#a9cf40ecf1b9b5c29507fe92a03f37a3c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface::VertexBufferBinding()'],['../a00835.html#a9cf40ecf1b9b5c29507fe92a03f37a3c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh::VertexBufferBinding()']]],
  ['vertexinterface',['VertexInterface',['../a00899.html#aa9bbcbcddafbf2d738cd57165c1f1d90',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::VertexInterface::VertexInterface()'],['../a00899.html#ab0a4759527012a701dcdf835659c9cd3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::VertexInterface::VertexInterface(Level const &amp;parent, Level const &amp;child)']]],
  ['vertexinterface',['VertexInterface',['../a00899.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal']]],
  ['vertexvalencetable',['VertexValenceTable',['../a00591.html#a2fbf111cac9d122eeaec5c0cb73fa77d',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable']]],
  ['vertexweight',['VertexWeight',['../a00875.html#a11be1fef88dd82e77f233c7bb6a6cfcd',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::VertexWeight(int index) const'],['../a00875.html#a694de304af7369f54ea1e7a82b33dab0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::VertexWeight(int index)']]],
  ['vertindex',['vertIndex',['../a00595.html#a46d1a8129375c3ee40a33a81d44b685a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle']]],
  ['vertindicesperface',['vertIndicesPerFace',['../a00659.html#a3f2274c4d3dd54c4e24144e504972b34',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyDescriptor']]],
  ['vspan',['VSpan',['../a00939.html#a2ca53d87b333ea3aec0ea8a9ee0f026a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::VSpan']]],
  ['vspan',['VSpan',['../a00939.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['vtag',['VTag',['../a00927.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['vtag',['VTag',['../a00927.html#a1485c3eac4dedaa280e0d4f79d215332',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::VTag']]],
  ['vtagsize',['VTagSize',['../a00927.html#acc50ae400672aed389aa46a330ee320e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::VTag']]],
  ['vtx_5fboundary_5fedge_5fand_5fcorner',['VTX_BOUNDARY_EDGE_AND_CORNER',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417eac6e5f52f358d3b6d62cc2b708a5a8757',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]],
  ['vtx_5fboundary_5fedge_5fonly',['VTX_BOUNDARY_EDGE_ONLY',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417ea9240987283549b42eeb262f088b68fdf',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]],
  ['vtx_5fboundary_5fnone',['VTX_BOUNDARY_NONE',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417ea5d15ed470f1f0ecce0549282de54a3ba',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]],
  ['vtxboundaryinterpolation',['VtxBoundaryInterpolation',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]]
];

==> opensubdiv-3.1.1-2-i686.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/all_14.js <==
var searchData=
[
  ['validate',['validate',['../a00903.html#a3566e1a9ec7fedc6e4fc47fab7c18532',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['validatefulltopology',['validateFullTopology',['../a00691.html#adaa22b025e8615d6e4281a86b794e5df',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory::Options']]],
  ['validatetopology',['validateTopology',['../a00923.html#a544d8f43ad23d13e196a9e3ba246d7df',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::validateTopology()'],['../a00667.html#a640a101c65375bded32722376e651f97',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyLevel::ValidateTopology()']]],
  ['validationcallback',['ValidationCallback',['../a00923.html#adb073794f0d56ccbf4c24ffae81ac6fe',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['value_5ftype',['value_type',['../a00883.html#a0caff2a05d659a02367f0f31ae29e45c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::ConstArray::value_type()'],['../a00887.html#a0caff2a05d659a02367f0f31ae29e45c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::Array::value_type()']]],
  ['valueindices',['valueIndices',['../a00663.html#a123fe78d0e97dc72f5dfd9f27f93f699',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyDescriptor::FVarChannel']]],
  ['valuetag',['ValueTag',['../a00911.html',1,'FVarLevel::ValueTag'],['../a00911.html#afa63533ac54c95a41f1dda16085401b0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel::ValueTag::ValueTag()']]],
  ['valuetagarray',['ValueTagArray',['../a00903.html#a59542ed688e97fbb07d38d8488416d9b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['valuetagsize',['ValueTagSize',['../a00911.html#a889d7ecab94d64e8abd73e4d632db45f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel::ValueTag']]],
  ['valuetopologymatches',['valueTopologyMatches',['../a00903.html#ab72baf3e3db74e2af11b59dbf18312e4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['vertexbuffer',['VertexBuffer',['../a00835.html#a722ca2b35d7001c0eeb6298f2c3704ca',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh']]],
  ['vertexbufferbinding',['VertexBufferBinding',['../a00763.html#a2d85a5ed6ddcef5023c9ef2e6fdd38a5',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::D3D11PatchTable::VertexBufferBinding()'],['../a00791.html#a02af2ea2e9328a776b5b0bb3edf88864',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::GLPatchTable::VertexBufferBinding()'],['../a00823.html#a9cf40ecf1b9b5c29507fe92a03f37a3c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface::VertexBufferBinding()'],['../a00835.html#a9cf40ecf1b9b5c29507fe92a03f37a3c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh::VertexBufferBinding()']]],
  ['vertexinterface',['VertexInterface',['../a00899.html',1,'VertexInterface'],['../a00899.html#aa9bbcbcddafbf2d738cd57165c1f1d90',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::VertexInterface::VertexInterface()'],['../a00899.html#ab0a4759527012a701dcdf835659c9cd3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::VertexInterface::VertexInterface(Level const &amp;parent, Level const &amp;child)']]],
  ['vertexvalencetable',['VertexValenceTable',['../a00591.html#a2fbf111cac9d122eeaec5c0cb73fa77d',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable']]],
  ['vertexweight',['VertexWeight',['../a00875.html#a11be1fef88dd82e77f233c7bb6a6cfcd',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::VertexWeight(int index) const'],['../a00875.html#a694de304af7369f54ea1e7a82b33dab0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::VertexWeight(int index)']]],
  ['vertindex',['vertIndex',['../a00595.html#a46d1a8129375c3ee40a33a81d44b685a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::PatchHandle']]],
  ['vertindicesperface',['vertIndicesPerFace',['../a00659.html#a3f2274c4d3dd54c4e24144e504972b34',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyDescriptor']]],
  ['vspan',['VSpan',['../a00939.html',1,'Level::VSpan'],['../a00939.html#a2ca53d87b333ea3aec0ea8a9ee0f026a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::VSpan::VSpan()']]],
  ['vtag',['VTag',['../a00927.html',1,'Level::VTag'],['../a00927.html#a1485c3eac4dedaa280e0d4f79d215332',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::VTag::VTag()']]],
  ['vtagsize',['VTagSize',['../a00927.html#acc50ae400672aed389aa46a330ee320e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::VTag']]],
  ['vtx_5fboundary_5fedge_5fand_5fcorner',['VTX_BOUNDARY_EDGE_AND_CORNER',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417eac6e5f52f358d3b6d62cc2b708a5a8757',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]],
  ['vtx_5fboundary_5fedge_5fonly',['VTX_BOUNDARY_EDGE_ONLY',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417ea9240987283549b42eeb262f088b68fdf',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]],
  ['vtx_5fboundary_5fnone',['VTX_BOUNDARY_NONE',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417ea5d15ed470f1f0ecce0549282de54a3ba',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]],
  ['vtxboundaryinterpolation',['VtxBoundaryInterpolation',['../a00867.html#acbf78f1a6abfc8db080ef7fb3c3f417e',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Options']]]
];
